==> senior_design_system-0.17.0.tar.gz: lib/components/senior_action_button/senior_action_button_widget.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_action_button_style.dart';
import '../../themes/senior_theme.dart';
import '../../themes/senior_theme_provider.dart';

enum SeniorActionButtonSize {
  small,
  medium,
}

class SeniorActionButton extends StatelessWidget {
  const SeniorActionButton({
    Key? key,
    required this.icon,
    this.onLongPress,
    required this.onTap,
    this.size = SeniorActionButtonSize.small,
    this.style,
  }) : super(key: key);

  final IconData icon;
  final VoidCallback? onLongPress;
  final VoidCallback onTap;
  final SeniorActionButtonSize size;
  final SeniorActionButtonStyle? style;

  factory SeniorActionButton.press({
    required IconData icon,
    VoidCallback? onLongPress,
    required VoidCallback onTap,
    SeniorActionButtonStyle? style,
  }) = _SeniorPressActionButton;

  double _getButtonDiameter() {
    switch (size) {
      case SeniorActionButtonSize.small:
        return 32.0;
      case SeniorActionButtonSize.medium:
        return 40.0;
    }
  }

  double _getButtonIconSize() {
    switch (size) {
      case SeniorActionButtonSize.small:
        return 16.0;
      case SeniorActionButtonSize.medium:
        return 24.0;
    }
  }

  @override
  Widget build(BuildContext context) {
    final double buttonDiameter = _getButtonDiameter();
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return Ink(
      height: buttonDiameter,
      width: buttonDiameter,
      decoration: BoxDecoration(
        color: theme?.actionButtonTheme?.style?.color ??
            defaultTheme.actionButtonTheme?.style?.color ??
            Colors.transparent,
        shape: BoxShape.circle,
      ),
      child: InkWell(
        onTap: onTap,
        onLongPress: onLongPress,
        splashColor: theme?.actionButtonTheme?.style?.splashColor ??
            defaultTheme.actionButtonTheme?.style?.splashColor ??
            SeniorColors.neutralColor200,
        borderRadius: BorderRadius.circular(buttonDiameter / 2),
        child: Center(
          child: FaIcon(
            icon,
            color: style?.iconColor ??
                theme?.actionButtonTheme?.style?.iconColor ??
                defaultTheme.actionButtonTheme?.style?.iconColor ??
                SeniorColors.secondaryColor900,
            size: _getButtonIconSize(),
          ),
        ),
      ),
    );
  }
}

class _SeniorPressActionButton extends SeniorActionButton {
  const _SeniorPressActionButton({
    Key? key,
    required IconData icon,
    VoidCallback? onLongPress,
    required VoidCallback onTap,
    SeniorActionButtonStyle? style,
  }) : super(
          key: key,
          icon: icon,
          onLongPress: onLongPress,
          onTap: onTap,
          style: style,
        );

  @override
  Widget build(BuildContext context) {
    final double buttonDiameter = 60.0;
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return Ink(
      height: buttonDiameter,
      width: buttonDiameter,
      decoration: BoxDecoration(
        color: style?.color ??
            theme?.pressActionButtonTheme?.style?.color ??
            defaultTheme.pressActionButtonTheme?.style?.color ??
            SeniorColors.primaryColor,
        shape: BoxShape.circle,
      ),
      child: InkWell(
        onTap: onTap,
        onLongPress: onLongPress,
        splashColor: theme?.pressActionButtonTheme?.style?.splashColor ??
            defaultTheme.pressActionButtonTheme?.style?.splashColor ??
            SeniorColors.primaryColor700,
        borderRadius: BorderRadius.circular(buttonDiameter / 2),
        child: Center(
          child: FaIcon(
            icon,
            color: style?.iconColor ??
                theme?.pressActionButtonTheme?.style?.iconColor ??
                defaultTheme.pressActionButtonTheme?.style?.iconColor ??
                SeniorColors.pureWhite,
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-0.26.2.tar.gz: lib/components/senior_action_button/senior_action_button_widget.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_action_button_style.dart';
import '../../themes/senior_theme.dart';
import '../../themes/senior_theme_provider.dart';

/// The possible sizes for the SeniorActionButton.
/// It can be [SeniorActionButtonSize.small] and [SeniorActionButtonSize.medium].
enum SeniorActionButtonSize {
  small,
  medium,
}

class SeniorActionButton extends StatelessWidget {
  /// Creates an Action Button component.
  ///
  /// The [icon] and [onTap] parameters are required.
  const SeniorActionButton({
    Key? key,
    required this.icon,
    this.onLongPress,
    required this.onTap,
    this.size = SeniorActionButtonSize.small,
    this.style,
  }) : super(key: key);

  /// Creates an Action Button component with Press variant.
  ///
  /// The [icon] and [onTap] parameters are required.
  factory SeniorActionButton.press({
    required IconData icon,
    VoidCallback? onLongPress,
    required VoidCallback onTap,
    SeniorActionButtonStyle? style,
  }) = _SeniorPressActionButton;

  /// The button icon.
  final IconData icon;

  /// Function performed when a long press on the button occurs.
  final VoidCallback? onLongPress;

  /// Function performed when the button is touched.
  final VoidCallback onTap;

  /// The size of the button.
  ///
  /// The default value is [SeniorActionButtonSize.small].
  final SeniorActionButtonSize size;

  /// The component's style definitions.
  ///
  /// Allows you to configure:
  /// [SeniorActionButtonStyle.color] the button color.
  /// [SeniorActionButtonStyle.iconColor] the color of the button icon.
  /// [SeniorActionButtonStyle.splashColor] the color of the splash effect of the button touch.
  final SeniorActionButtonStyle? style;

  double _getButtonDiameter() {
    switch (size) {
      case SeniorActionButtonSize.small:
        return 32.0;
      case SeniorActionButtonSize.medium:
        return 40.0;
    }
  }

  double _getButtonIconSize() {
    switch (size) {
      case SeniorActionButtonSize.small:
        return 16.0;
      case SeniorActionButtonSize.medium:
        return 24.0;
    }
  }

  @override
  Widget build(BuildContext context) {
    final double buttonDiameter = _getButtonDiameter();
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme =
        SeniorThemeProvider.getDefaultTheme(context);

    return Ink(
      height: buttonDiameter,
      width: buttonDiameter,
      decoration: BoxDecoration(
        color: theme?.actionButtonTheme?.style?.color ??
            defaultTheme.actionButtonTheme?.style?.color ??
            Colors.transparent,
        shape: BoxShape.circle,
      ),
      child: InkWell(
        onTap: onTap,
        onLongPress: onLongPress,
        splashColor: theme?.actionButtonTheme?.style?.splashColor ??
            defaultTheme.actionButtonTheme?.style?.splashColor ??
            SeniorColors.neutralColor200,
        borderRadius: BorderRadius.circular(buttonDiameter / 2),
        child: Center(
          child: Icon(
            icon,
            color: style?.iconColor ??
                theme?.actionButtonTheme?.style?.iconColor ??
                defaultTheme.actionButtonTheme?.style?.iconColor ??
                SeniorColors.secondaryColor900,
            size: _getButtonIconSize(),
          ),
        ),
      ),
    );
  }
}

class _SeniorPressActionButton extends SeniorActionButton {
  const _SeniorPressActionButton({
    Key? key,
    required IconData icon,
    VoidCallback? onLongPress,
    required VoidCallback onTap,
    SeniorActionButtonStyle? style,
  }) : super(
          key: key,
          icon: icon,
          onLongPress: onLongPress,
          onTap: onTap,
          style: style,
        );

  @override
  Widget build(BuildContext context) {
    const double buttonDiameter = 60.0;
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme =
        SeniorThemeProvider.getDefaultTheme(context);

    return Ink(
      height: buttonDiameter,
      width: buttonDiameter,
      decoration: BoxDecoration(
        color: style?.color ??
            theme?.pressActionButtonTheme?.style?.color ??
            defaultTheme.pressActionButtonTheme?.style?.color ??
            SeniorColors.primaryColor,
        shape: BoxShape.circle,
      ),
      child: InkWell(
        onTap: onTap,
        onLongPress: onLongPress,
        splashColor: theme?.pressActionButtonTheme?.style?.splashColor ??
            defaultTheme.pressActionButtonTheme?.style?.splashColor ??
            SeniorColors.primaryColor700,
        borderRadius: BorderRadius.circular(buttonDiameter / 2),
        child: Center(
          child: Icon(
            icon,
            color: style?.iconColor ??
                theme?.pressActionButtonTheme?.style?.iconColor ??
                defaultTheme.pressActionButtonTheme?.style?.iconColor ??
                SeniorColors.pureWhite,
          ),
        ),
      ),
    );
  }
}
